@@ -33,8 +33,9 @@ proximity_average <- function(G, source, targets){
   source = source [source %in% V(G)$name] %>% unique
   targets = targets [targets %in% V(G)$name]%>% unique
   out = NA
+  igraph::E(G)$weight = 1
   if(length(source)> 0 & length(targets)> 0){
-    d <-  igraph::distances(G, source, targets)
+    d <-  igraph::distances(G, source, targets, weights = NULL)
     out = apply(d, 2, min) %>% mean()
   }
   return(out)
